@@ -108,33 +108,12 @@ setReplaceMethod("names", "CompressedList",
 ### when calling this from another package.
 ###
 
-### Hackery to avoid R CMD check warning for using an internal...
-islistfactor <- function(x) {
-    eval(as.call(list(quote(.Internal),
-                      substitute(islistfactor(x, FALSE), list(x=x)))))
-}
-
-compress_listData <- function(x, elementType = NULL) {
-    if (length(x) > 0L) {
-        if (islistfactor(x)) {
-            x <- unlist(x, recursive=FALSE, use.names=FALSE)
-        } else if (length(dim(x[[1L]])) < 2L) {
-            x <- do.call(c, unname(x))
-        } else {
-            x <- do.call(rbind, unname(x))
-        }
-    } else {
-        x <- vector()
-    }
-    x
-}
-
 .reconcile_mcols <- function(x) {
   x_mcols <- mcols(x, use.names=FALSE)
   if (is(x_mcols, "DataFrame") &&
       nrow(x_mcols) == 0L && ncol(x_mcols) == 0L)
     {
-      x_mcols <- S4Vectors:::make_zero_col_DataFrame(length(x))
+      x_mcols <- make_zero_col_DFrame(length(x))
       mcols(x) <- x_mcols
     }
   x
@@ -181,7 +160,7 @@ new_CompressedList_from_list <- function(Class, x, ..., mcols)
         return(new2(Class, partitioning=ans_partitioning, ...,
                            elementMetadata=mcols, check=FALSE))
     }
-    ans_unlistData <- compress_listData(x, ans_elementType)
+    ans_unlistData <- S4Vectors:::compress_listData(x, ans_elementType)
     if (missing(mcols)) {
         ans <- new2(Class, unlistData=ans_unlistData,
                            partitioning=ans_partitioning, ...,
@@ -224,7 +203,7 @@ coerceToCompressedList <- function(from, element.type = NULL, ...) {
     return(from)
   if (is.list(from) || (is(from, "List") && !is(from, "DataFrame"))) {
     if (is.list(from)) {
-      v <- compress_listData(from, element.type)
+      v <- S4Vectors:::compress_listData(from, element.type)
     } else {
       v <- unlist(from, use.names = FALSE)
     }
@@ -415,3 +394,45 @@ setMethod("revElements", "CompressedList",
     }
 )
 
+### - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+### Recycling
+###
+
+repLengthOneElements <- function(x, times) {
+    x@unlistData <- rep(x@unlistData, times)
+    x@partitioning@end <- cumsum(times)
+    x
+}
+
+recycleListElements <- function(x, newlen) {
+    x_eltNROWS <- elementNROWS(x)
+    if (identical(x_eltNROWS, newlen)) {
+        return(x)
+    }
+    if (all(x_eltNROWS == 1L)) {
+        ans <- repLengthOneElements(x, newlen)
+    } else {
+        if (any(x_eltNROWS == 0L & newlen > 0L)) {
+            if (is(x, "AtomicList")) {
+                x[x_eltNROWS == 0L & newlen > 0L] <- list(NA)
+            } else {
+                stop("recycling of zero-length elements not supported")
+            }
+            x_eltNROWS <- elementNROWS(x)
+        }
+        times <- ceiling(newlen / x_eltNROWS)
+        times[x_eltNROWS == 0L] <- 0L
+        ans_ir <- rep(as(PartitioningByEnd(x), "IRanges"), times)
+        remainder <- newlen %% x_eltNROWS
+        remainder[x_eltNROWS == 0L] <- 0L
+        if (any(remainder > 0L)) {
+            last <- cumsum(times)
+            width(ans_ir)[last[remainder > 0]] <- remainder[remainder > 0]
+            warning("Some element lengths are not multiples of their ",
+                    "corresponding element length in ", deparse(substitute(x)))
+        }
+        ans <- relist(extractROWS(unlist(x, use.names=FALSE), ans_ir),
+                      PartitioningByWidth(newlen))
+    }
+    ans
+}
