@@ -17,14 +17,14 @@ setClass("Views",
 
 
 ### - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-### vertical_slot_names()
+### parallel_slot_names()
 ###
 
-### Combine the new "vertical slots" with those of the parent class. Make
-### sure to put the new vertical slots **first**. See R/bindROWS.R file in
-### the S4Vectors package for what slots should or should not be considered
-### "vertical".
-setMethod("vertical_slot_names", "Views",
+### Combine the new "parallel slots" with those of the parent class. Make
+### sure to put the new parallel slots **first**. See R/Vector-class.R file
+### in the S4Vectors package for what slots should or should not be considered
+### "parallel".
+setMethod("parallel_slot_names", "Views",
     function(x) c("ranges", callNextMethod())
 )
 
