@@ -162,52 +162,6 @@ setMethod("findOverlaps", c("IntegerRangesList", "IntegerRangesList"),
             ans
           })
 
-.findOverlaps_RangedData_defunct_msg <- c(
-    "RangedData objects are deprecated and the \"findOverlaps\" methods ",
-    "for RangedData objects are now defunct. ",
-    "Please migrate your code to use GRanges or GRangesList objects instead. ",
-    "See IMPORTANT NOTE in ?RangedData"
-)
-
-setMethod("findOverlaps", c("RangedData", "RangedData"),
-          function(query, subject, maxgap = -1L, minoverlap = 0L,
-                   type = c("any", "start", "end", "within", "equal"),
-                   select = c("all", "first", "last", "arbitrary"),
-                   drop = FALSE)
-          {
-            .Defunct(msg=wmsg(.findOverlaps_RangedData_defunct_msg))
-            findOverlaps(ranges(query), ranges(subject),
-                         maxgap = maxgap, minoverlap = minoverlap,
-                         type = match.arg(type), select = match.arg(select),
-                         drop = drop)
-          })
-
-setMethod("findOverlaps", c("RangedData", "IntegerRangesList"),
-          function(query, subject, maxgap = -1L, minoverlap = 0L,
-                   type = c("any", "start", "end", "within", "equal"),
-                   select = c("all", "first", "last", "arbitrary"),
-                   drop = FALSE)
-          {
-            .Defunct(msg=wmsg(.findOverlaps_RangedData_defunct_msg))
-            findOverlaps(ranges(query), subject,
-                         maxgap = maxgap, minoverlap = minoverlap,
-                         type = match.arg(type), select = match.arg(select),
-                         drop = drop)
-          })
-
-setMethod("findOverlaps", c("IntegerRangesList", "RangedData"),
-          function(query, subject, maxgap = -1L, minoverlap = 0L,
-                   type = c("any", "start", "end", "within", "equal"),
-                   select = c("all", "first", "last", "arbitrary"),
-                   drop = FALSE)
-          {
-            .Defunct(msg=wmsg(.findOverlaps_RangedData_defunct_msg))
-            findOverlaps(query, ranges(subject),
-                         maxgap = maxgap, minoverlap = minoverlap,
-                         type = match.arg(type), select = match.arg(select),
-                         drop = drop)
-          })
-
 setMethod("findOverlaps", c("Pairs", "missing"),
           function (query, subject, maxgap = -1L, minoverlap = 0L,
                     type = c("any",  "start", "end", "within", "equal"),
@@ -252,7 +206,7 @@ setGeneric("countOverlaps", signature=c("query", "subject"),
         standardGeneric("countOverlaps")
 )
 
-.countOverlaps_default <-
+.default_countOverlaps <-
     function(query, subject, maxgap=-1L, minoverlap=0L,
              type=c("any", "start", "end", "within", "equal"),
              ...)
@@ -276,9 +230,9 @@ setGeneric("countOverlaps", signature=c("query", "subject"),
     ans
 }
 
-setMethod("countOverlaps", c("Vector", "Vector"), .countOverlaps_default)
-setMethod("countOverlaps", c("integer", "Vector"), .countOverlaps_default)
-setMethod("countOverlaps", c("Vector", "missing"), .countOverlaps_default)
+setMethod("countOverlaps", c("Vector", "Vector"), .default_countOverlaps)
+setMethod("countOverlaps", c("integer", "Vector"), .default_countOverlaps)
+setMethod("countOverlaps", c("Vector", "missing"), .default_countOverlaps)
 
 countOverlaps_IntegerRanges <- function(query, subject,
               maxgap=-1L, minoverlap=0L,
@@ -320,7 +274,8 @@ setGeneric("overlapsAny", signature=c("query", "subject"),
         standardGeneric("overlapsAny")
 )
 
-.overlapsAny_default <-
+### NOT exported but used in the bsseq package.
+default_overlapsAny <-
     function(query, subject, maxgap=-1L, minoverlap=0L,
              type=c("any", "start", "end", "within", "equal"),
              ...)
@@ -342,9 +297,9 @@ setGeneric("overlapsAny", signature=c("query", "subject"),
     !is.na(ahit)
 }
 
-setMethod("overlapsAny", c("Vector", "Vector"), .overlapsAny_default)
-setMethod("overlapsAny", c("integer", "Vector"), .overlapsAny_default)
-setMethod("overlapsAny", c("Vector", "missing"), .overlapsAny_default)
+setMethod("overlapsAny", c("Vector", "Vector"), default_overlapsAny)
+setMethod("overlapsAny", c("integer", "Vector"), default_overlapsAny)
+setMethod("overlapsAny", c("Vector", "missing"), default_overlapsAny)
 
 setMethod("overlapsAny", c("IntegerRangesList", "IntegerRangesList"),
     function(query, subject, maxgap=-1L, minoverlap=0L,
@@ -395,20 +350,22 @@ setGeneric("subsetByOverlaps", signature=c("x", "ranges"),
         standardGeneric("subsetByOverlaps")
 )
 
-setMethod("subsetByOverlaps", c("Vector", "Vector"),
+### NOT exported but used in the bsseq package.
+default_subsetByOverlaps <-
     function(x, ranges, maxgap=-1L, minoverlap=0L,
-             type=c("any", "start", "end", "within", "equal"), invert=FALSE,
-             ...)
-    {
-        ov_any <- overlapsAny(x, ranges,
-                              maxgap=maxgap, minoverlap=minoverlap,
-                              type=match.arg(type),
-                              ...)
-        if (invert)
-            ov_any <- !ov_any
-        x[ov_any]
-    }
-)
+             type=c("any", "start", "end", "within", "equal"),
+             invert=FALSE, ...)
+{
+    ov_any <- overlapsAny(x, ranges,
+                          maxgap=maxgap, minoverlap=minoverlap,
+                          type=match.arg(type),
+                          ...)
+    if (invert)
+        ov_any <- !ov_any
+    x[ov_any]
+}
+
+setMethod("subsetByOverlaps", c("Vector", "Vector"), default_subsetByOverlaps)
 
 
 ### - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
